@@ -115,7 +115,7 @@ class ServerNameFilter(SentryFilter):
     column = 'server_name'
 
     def get_query_set(self, queryset):
-        return queryset.filter(message_set__server_name=self.get_value())
+        return queryset.filter(message_set__server_name=self.get_value()).distinct()
 
 class LevelFilter(SentryFilter):
     label = 'Level'
