@@ -127,6 +127,10 @@ class GroupedMessage(MessageBase):
     def __unicode__(self):
         return "(%s) %s" % (self.times_seen, self.error())
 
+    @models.permalink
+    def get_absolute_url(self):
+        return ('sentry-group', (self.pk), {})
+
     def natural_key(self):
         return (self.logger, self.view, self.checksum)
 
@@ -149,9 +153,9 @@ class GroupedMessage(MessageBase):
     def get_score_clause(cls):
         engine = get_db_engine()
         if engine.startswith('postgresql'):
-            return 'times_seen * 3600 + last_seen::abstime::int'
+            return 'log(times_seen) * 600 + last_seen::abstime::int'
         if engine.startswith('mysql'):
-            return 'times_seen * 3600 + unix_timestamp(last_seen)'
+            return 'log(times_seen) * 600 + unix_timestamp(last_seen)'
         return 'times_seen'
 
     def mail_admins(self, request=None, fail_silently=True):
@@ -208,8 +212,9 @@ class Message(MessageBase):
             self.checksum = construct_checksum(**self.__dict__)
         super(Message, self).save(*args, **kwargs)
 
+    @models.permalink
     def get_absolute_url(self):
-        return self.url
+        return ('sentry-group-message', (self.group_id, self.pk), {})
     
     def shortened_url(self):
         if not self.url:
@@ -256,4 +261,4 @@ class FilterValue(models.Model):
 
 # XXX: Django sucks and we can't listen to our specific app
 # post_syncdb.connect(GroupedMessage.create_sort_index, sender=__name__)
-post_syncdb.connect(GroupedMessage.create_sort_index)
\ No newline at end of file
+post_syncdb.connect(GroupedMessage.create_sort_index, sender=sys.modules[__name__])
\ No newline at end of file
