@@ -121,7 +121,7 @@ def index(request):
         message_list = message_list.order_by('-first_seen')
     else:
         sort = 'priority'
-        message_list = message_list.order_by('-score', '-last_seen').distinct()
+        message_list = message_list.order_by('-score', '-last_seen')
 
     
     any_filter = False
@@ -159,7 +159,7 @@ def ajax_handler(request):
             message_list = message_list.order_by('-first_seen')
         else:
             sort = 'priority'
-            message_list = message_list.order_by('-score', '-last_seen').distinct()
+            message_list = message_list.order_by('-score', '-last_seen')
         
         for filter_ in filters:
             if not filter_.is_set():
@@ -233,6 +233,7 @@ def group(request, group_id):
     
     json_data = iter_data(obj)
     
+    # TODO: this should be a template tag
     engine = get_db_engine()
     if SimpleLineChart and not engine.startswith('sqlite'):
         today = datetime.datetime.now()
@@ -259,7 +260,111 @@ def group(request, group_id):
         chart.set_line_style(1, 1)
         chart_url = chart.get_url()
     
-    return render_to_response('sentry/group.html', locals())
+    return render_to_response('sentry/group/details.html', locals())
+
+@login_required
+def group_message_list(request, group_id):
+    group = get_object_or_404(GroupedMessage, pk=group_id)
+
+    message_list = group.message_set.all().order_by('-datetime')
+    
+    unique_urls = message_list.filter(url__isnull=False).values_list('url', 'logger', 'view', 'checksum').annotate(times_seen=Count('url')).values('url', 'times_seen').order_by('-times_seen')
+    
+    unique_servers = message_list.filter(server_name__isnull=False).values_list('server_name', 'logger', 'view', 'checksum').annotate(times_seen=Count('server_name')).values('server_name', 'times_seen').order_by('-times_seen')
+    
+    engine = get_db_engine()
+    if SimpleLineChart and not engine.startswith('sqlite'):
+        today = datetime.datetime.now()
+
+        chart_qs = message_list\
+                          .filter(datetime__gte=today - datetime.timedelta(hours=24))\
+                          .extra(select={'hour': 'extract(hour from datetime)'}).values('hour')\
+                          .annotate(num=Count('id')).values_list('hour', 'num')
+
+        rows = dict(chart_qs)
+        if rows:
+            max_y = max(rows.values())
+        else:
+            max_y = 1
+
+        chart = SimpleLineChart(300, 80, y_range=[0, max_y])
+        chart.add_data([max_y]*30)
+        chart.add_data([rows.get((today-datetime.timedelta(hours=d)).hour, 0) for d in range(0, 24)][::-1])
+        chart.add_data([0]*30)
+        chart.fill_solid(chart.BACKGROUND, 'eeeeee')
+        chart.add_fill_range('eeeeee', 0, 1)
+        chart.add_fill_range('e0ebff', 1, 2)
+        chart.set_colours(['eeeeee', '999999', 'eeeeee'])
+        chart.set_line_style(1, 1)
+        chart_url = chart.get_url()
+    
+    page = 'messages'
+    
+    return render_to_response('sentry/group/message_list.html', locals())
+
+@login_required
+def group_message_details(request, group_id, message_id):
+    group = get_object_or_404(GroupedMessage, pk=group_id)
+
+    message_list = group.message_set.all()
+
+    message = get_object_or_404(group.message_set, pk=message_id)
+    
+    unique_urls = message_list.filter(url__isnull=False).values_list('url', 'logger', 'view', 'checksum').annotate(times_seen=Count('url')).values('url', 'times_seen').order_by('-times_seen')
+    
+    unique_servers = message_list.filter(server_name__isnull=False).values_list('server_name', 'logger', 'view', 'checksum').annotate(times_seen=Count('server_name')).values('server_name', 'times_seen').order_by('-times_seen')
+    
+    if '__sentry__' in message.data:
+        module, args, frames = message.data['__sentry__']['exc']
+        message.class_name = str(message.class_name)
+        # We fake the exception class due to many issues with imports/builtins/etc
+        exc_type = type(message.class_name, (Exception,), {})
+        exc_value = exc_type(message.message)
+
+        exc_value.args = args
+    
+        reporter = ImprovedExceptionReporter(message.request, exc_type, exc_value, frames, message.data['__sentry__'].get('template'))
+        traceback = mark_safe(reporter.get_traceback_html())
+    elif group.traceback:
+        traceback = mark_safe('<pre>%s</pre>' % (group.traceback,))
+    
+    def iter_data(obj):
+        for k, v in obj.data.iteritems():
+            if k.startswith('_') or k in ['url']:
+                continue
+            yield k, v
+    
+    json_data = iter_data(message)
+    
+    engine = get_db_engine()
+    if SimpleLineChart and not engine.startswith('sqlite'):
+        today = datetime.datetime.now()
+
+        chart_qs = message_list\
+                          .filter(datetime__gte=today - datetime.timedelta(hours=24))\
+                          .extra(select={'hour': 'extract(hour from datetime)'}).values('hour')\
+                          .annotate(num=Count('id')).values_list('hour', 'num')
+
+        rows = dict(chart_qs)
+        if rows:
+            max_y = max(rows.values())
+        else:
+            max_y = 1
+
+        chart = SimpleLineChart(300, 80, y_range=[0, max_y])
+        chart.add_data([max_y]*30)
+        chart.add_data([rows.get((today-datetime.timedelta(hours=d)).hour, 0) for d in range(0, 24)][::-1])
+        chart.add_data([0]*30)
+        chart.fill_solid(chart.BACKGROUND, 'eeeeee')
+        chart.add_fill_range('eeeeee', 0, 1)
+        chart.add_fill_range('e0ebff', 1, 2)
+        chart.set_colours(['eeeeee', '999999', 'eeeeee'])
+        chart.set_line_style(1, 1)
+        chart_url = chart.get_url()
+    
+    page = 'messages'
+    
+    return render_to_response('sentry/group/message.html', locals())
 
 @csrf_exempt
 def store(request):
